FlutterDefenderPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • FlutterDefenderPlatform

Constructors

FlutterDefenderPlatform()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearLifecycleSnapshot() Future<void>
getAdvancedSecuritySignals() Future<AdvancedSecuritySignals>
getRuntimeState() Future<NativeRuntimeState>
loadLifecycleSnapshot() Future<LifecycleSnapshot>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveLifecycleSnapshot(LifecycleSnapshot snapshot) Future<void>
secureClearAll() Future<void>
secureDelete(String key) Future<void>
secureRead(String key) Future<String?>
secureWrite({required String key, required String value}) Future<void>
setCallbacks(FlutterDefenderPlatformCallbacks? callbacks) → void
setProtectionState({required bool secureActive, required bool overlayHardeningActive}) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance FlutterDefenderPlatform
getter/setter pair