FlutterDefenderPlatformCallbacks class
Constructors
- FlutterDefenderPlatformCallbacks({VoidCallback? onScreenshotDetected, FlutterDefenderBoolCallback? onScreenCaptureChanged, VoidCallback? onOverlayViolation, FlutterDefenderBoolCallback? onForegroundStateChanged})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onForegroundStateChanged → FlutterDefenderBoolCallback?
-
final
- onOverlayViolation → VoidCallback?
-
final
- onScreenCaptureChanged → FlutterDefenderBoolCallback?
-
final
- onScreenshotDetected → VoidCallback?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited