FlutterDefenderLocalizations class abstract

Callers can lookup localized strings with an instance of FlutterDefenderLocalizations returned by FlutterDefenderLocalizations.of(context).

Applications need to include FlutterDefenderLocalizations.delegate() in their app's localizationDelegates list, and the locales they support in the app's supportedLocales list. For example:

import 'l10n/flutter_defender_localizations.dart';

return MaterialApp(
  localizationsDelegates: FlutterDefenderLocalizations.localizationsDelegates,
  supportedLocales: FlutterDefenderLocalizations.supportedLocales,
  home: MyApplicationHome(),
);

Update pubspec.yaml

Please make sure to update your pubspec.yaml to include the following packages:

dependencies:
  # Internationalization support.
  flutter_localizations:
    sdk: flutter
  intl: any # Use the pinned version from flutter_localizations

  # Rest of dependencies

iOS Applications

iOS applications define key application metadata, including supported locales, in an Info.plist file that is built into the application bundle. To configure the locales supported by your app, you’ll need to edit this file.

First, open your project’s ios/Runner.xcworkspace Xcode workspace file. Then, in the Project Navigator, open the Info.plist file under the Runner project’s Runner folder.

Next, select the Information Property List item, select Add Item from the Editor menu, then select Localizations from the pop-up menu.

Select and expand the newly-created Localizations item then, for each locale your application supports, add a new item and select the locale you wish to add from the pop-up menu in the Value field. This list should be consistent with the languages listed in the FlutterDefenderLocalizations.supportedLocales property.

Implementers

Constructors

FlutterDefenderLocalizations(String locale)

Properties

blockingScreenTitle String
No description provided for @blockingScreenTitle.
no setter
emulatorReleaseBlocked String
No description provided for @emulatorReleaseBlocked.
no setter
foregroundRequired String
No description provided for @foregroundRequired.
no setter
hashCode int
The hash code for this object.
no setterinherited
localeName String
final
overlaysBlocked String
No description provided for @overlaysBlocked.
no setter
proxyOrVpnBlocked String
No description provided for @proxyOrVpnBlocked.
no setter
rootOrJailbreakBlocked String
No description provided for @rootOrJailbreakBlocked.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenCaptureBlocked String
No description provided for @screenCaptureBlocked.
no setter
screenshotsBlocked String
No description provided for @screenshotsBlocked.
no setter
tamperingBlocked String
No description provided for @tamperingBlocked.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

of(BuildContext context) FlutterDefenderLocalizations?

Constants

delegate → const LocalizationsDelegate<FlutterDefenderLocalizations>
localizationsDelegates → const List<LocalizationsDelegate>
A list of this localizations delegate along with the default localizations delegates.
supportedLocales → const List<Locale>
A list of this localizations delegate's supported locales.