FlutterDefenderLocalizationsEn class
The translations for English (en).
- Inheritance
-
- Object
- FlutterDefenderLocalizations
- FlutterDefenderLocalizationsEn
Constructors
- FlutterDefenderLocalizationsEn([String locale = 'en'])
Properties
- blockingScreenTitle → String
-
No description provided for @blockingScreenTitle.
no setteroverride
- emulatorReleaseBlocked → String
-
No description provided for @emulatorReleaseBlocked.
no setteroverride
- foregroundRequired → String
-
No description provided for @foregroundRequired.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- localeName → String
-
finalinherited
- overlaysBlocked → String
-
No description provided for @overlaysBlocked.
no setteroverride
- proxyOrVpnBlocked → String
-
No description provided for @proxyOrVpnBlocked.
no setteroverride
- rootOrJailbreakBlocked → String
-
No description provided for @rootOrJailbreakBlocked.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screenCaptureBlocked → String
-
No description provided for @screenCaptureBlocked.
no setteroverride
- screenshotsBlocked → String
-
No description provided for @screenshotsBlocked.
no setteroverride
- tamperingBlocked → String
-
No description provided for @tamperingBlocked.
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited