proxyOrVpnBlocked property
No description provided for @proxyOrVpnBlocked.
In en, this message translates to: 'Security Policy: Proxy or VPN usage is not allowed for this protected screen.'
Implementation
@override
String get proxyOrVpnBlocked =>
'Security Policy: Proxy or VPN usage is not allowed for this protected screen.';