foregroundRequired property
No description provided for @foregroundRequired.
In en, this message translates to: 'Security Policy: Sensitive screens require the app to remain in the foreground.'
Implementation
@override
String get foregroundRequired =>
'Security Policy: Sensitive screens require the app to remain in the foreground.';